#import "@preview/springer-spaniel:0.1.0"
#import springer-spaniel.ctheorems: * // provides "proof", "theorem", "lemma"

// Set citation style
#set cite(style: "iso-690-author-date") // page info visible
//#set cite(style: "iso-690-numeric") // page info visible
//#set cite(style: "springer-basic")// no additional info visible (page number in square brackets)
//#set cite(style: "alphanumeric")// page info not visible


#show: springer-spaniel.template(
  title: [Few shot learning for anomaly detection Bachelor Thesis for AI],
  authors: (
    (
      name: "Lukas Heiligenbrunner",
      institute: "Johannes Kepler University",
      address: "Linz, Austria",
      email: "lukas.heiligenbrunner@gmail.com"
    ),
    // ... and so on
  ),
  abstract: lorem(75),

  // debug: true, // Highlights structural elements and links
  // frame: 1pt, // A border around the page for white on white display
  // printer-test: true, // Suitably placed CMYK printer tests
)

#let date =  datetime.today() // not today: datetime(year: 1969, month: 9, day: 6,)
#let k-number = "k12345678"

// set equation and heading numbering
#set math.equation(numbering: "(1)")
#set heading(numbering: "1.1")


// Pagebreak after level 1 headings
#show heading.where(level: 1): it => [
  #pagebreak(weak: true)
  #it
]

// show reference targets in brackets
#show ref: it => {
  let el = it.element
  if el != none and el.func() == heading {

    [#it (#el.body)]
  } else [#it]
}

// style table-of-contents
#show outline.entry.where(
  level: 1
): it => {
  v(1em, weak: true)
  strong(it)
}

// Table of contents.
#outline(
  title: {
    text(1.3em, weight: 700, "Contents")
    v(10mm)
  },
  indent: 2em,
  depth: 2
)<outline>
#pagebreak(weak: false)

#include "introduction.typ"
#include "materialandmethods.typ"
#include "implementation.typ"
#include "experimentalresults.typ"
#include "conclusionandoutlook.typ"

#set par(leading: 0.7em, first-line-indent: 0em, justify: true)
#bibliography("sources.bib", style: "apa")
